package Gtk2::NotificationBubble;

use 5.008;
use strict;
use warnings;

use Gtk2;

require DynaLoader;

our @ISA = qw(DynaLoader);


our $VERSION = '0.01';

sub dl_load_flags { 0x01 }

bootstrap Gtk2::NotificationBubble $VERSION;

# Preloaded methods go here.

1;
__END__

=head1 NAME

Gtk2::NotificationBubble - Perl interface to the EggNotificationBubble library

=head1 SYNOPSIS

  use Gtk2::NotificationBubble;
  use Gtk2::TrayIcon;
  Gtk2->init;

  my $icon= Gtk2::TrayIcon->new("test");
  my $label= Gtk2::Label->new("test");
  $icon->add($label);
  $icon->show_all;

  my $bubble = Gtk2::NotificationBubble->new;
  $bubble->attach($icon);
  $bubble->set("Hello", undef, "I'm a bubble!");
  $bubble->show(5000);

  Gtk2->main;

=head1 ABSTRACT

This module allows a Perl developer to display notification bubbles on
top of Gtk2 widgets. They look like tooltips with bevelled borders and
arrows. They can display an icon and a bold header.

=head1 DESCRIPTION

EggNotificationBubble is slated for inclusion in Gtk+ at some point, which is the
reason the C<Gtk2::NotificationBubble> namespace. As all egg libs, EggNotificationBubble
is not considered api stable and its not installed as a shared object.

This notification bubble is currently used in rhythmbox, and will be
merged in libegg soon. It has been written to replace the original
implementation of messages notification in EggTrayIcon.

=head1 METHODS

5 methods are available.

=over 4

=item $bubble = Gtk2::NotificationBubble->new

Creates the notification bubble widget.

=item $bublle->attach ($widget)

Attach the notification bubble to a widget.

=item $bubble->set ($notification_header, $icon, $notification_body)

Set the bubble content (bold header, left icon, and notification text)

=item $bubble->show($timeout)

Show the bubble for the specified amount of time (or forever if <= 0)

=item $bubble->hide

Hide the bubble

=item $bubble->force_window

Force the bubble window to be created.
This should never be called, it's done by the show method.

=back

=head1 SEE ALSO

L<Glib>, L<Gtk2>, L<Gtk2::Widget>

=head1 AUTHOR

Olivier Blin E<lt>oblin at mandriva dot comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2005 by the gtk2-perl team.

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with this library; if not, write to the 
Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
Boston, MA  02111-1307  USA.

=cut
